from setuptools import setup

setup(
    name="contrafacil",  # Nombre actualizado
    version="1.0",
    py_modules=["contrafacil"],  # Cambia aquí también
    description="Generador de contraseñas seguras",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="zerordia",
    author_email="alejo.duarte.2007@gmail.com",
    url="https://github.com/tuusuario/contrafacil",  # Cambia esto también
    entry_points={
        "console_scripts": [
            "contrafacil=contrafacil:main",  # Cambia aquí también
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
